@@ -28,6 +28,7 @@
 #include "notify.h"
 #include "pounce.h"
 #include "prefs.h"
+#include "privacy.h"
 #include "prpl.h"
 #include "request.h"
 #include "signals.h"
@@ -145,6 +146,8 @@ gaim_account_new(const char *username, const char *protocol_id)
 	account->ui_settings = g_hash_table_new_full(g_str_hash, g_str_equal,
 				g_free, (GDestroyNotify)g_hash_table_destroy);
 	account->system_log = NULL;
+	/* 0 is not a valid privacy setting */
+	account->perm_deny = GAIM_PRIVACY_ALLOW_ALL;
 
 	return account;
 }
