@@ -247,7 +247,8 @@ void gaim_blist_update_buddy_status(GaimBuddy *buddy, int status)
 		buddy->uc = status;
 		gaim_contact_compute_priority_buddy(gaim_buddy_get_contact(buddy));
 
-		if ((status & UC_UNAVAILABLE) != (old_status & UC_UNAVAILABLE)) {
+		if ((buddy->present != GAIM_BUDDY_SIGNING_OFF) && (buddy->present != GAIM_BUDDY_OFFLINE) &&
+			((status & UC_UNAVAILABLE) != (old_status & UC_UNAVAILABLE))) {
 			if (status & UC_UNAVAILABLE)
 				gaim_signal_emit(gaim_blist_get_handle(), "buddy-away", buddy);
 			else
@@ -2003,6 +2004,7 @@ static gboolean gaim_blist_read(const char *filename)
 		for (anode = privacy->child; anode; anode = anode->next) {
 			xmlnode *x;
 			GaimAccount *account;
+			int imode;
 			const char *acct_name, *proto, *mode, *protocol;
 
 			acct_name = xmlnode_get_attrib(anode, "name");
@@ -2018,7 +2020,8 @@ static gboolean gaim_blist_read(const char *filename)
 			if (!account)
 				continue;
 
-			account->perm_deny = atoi(mode);
+			imode = atoi(mode);
+			account->perm_deny = (imode != 0 ? imode : GAIM_PRIVACY_ALLOW_ALL);
 
 			for (x = anode->child; x; x = x->next) {
 				char *name;
