@@ -614,8 +614,6 @@ gaim_conv_window_switch_conversation(GaimConvWindow *win, unsigned int index)
 	if (ops != NULL && ops->switch_conversation != NULL)
 		ops->switch_conversation(win, index);
 
-	gaim_conversation_set_unseen(conv, GAIM_UNSEEN_NONE);
-
 	gaim_signal_emit(gaim_conversations_get_handle(),
 					 "conversation-switched", old_conv, conv);
 }
@@ -1387,17 +1385,32 @@ gaim_find_conversation_with_account(const char *name,
 	GaimConversation *c = NULL;
 	char *cuser;
 	GList *cnv;
+	GaimPluginProtocolInfo *prpl_info = NULL;
 
 	g_return_val_if_fail(name != NULL, NULL);
 
-	cuser = g_strdup(gaim_normalize(account, name));
+	if(account && account->gc && account->gc->prpl) {
+		prpl_info = GAIM_PLUGIN_PROTOCOL_INFO(account->gc->prpl);
+	}
+
+	if(prpl_info && prpl_info->options & OPT_PROTO_NO_NORMALIZE_CONV) {
+		cuser = g_strdup(name);
+	} else {
+		cuser = g_strdup(gaim_normalize(account, name));
+	}
 
 	for (cnv = gaim_get_conversations(); cnv != NULL; cnv = cnv->next) {
+		const char *cmp;
 		c = (GaimConversation *)cnv->data;
 
-		if (!gaim_utf8_strcasecmp(cuser,
-								  gaim_normalize(account, gaim_conversation_get_name(c))) &&
-			account == gaim_conversation_get_account(c)) {
+		if(prpl_info && prpl_info->options & OPT_PROTO_NO_NORMALIZE_CONV) {
+			cmp = gaim_conversation_get_name(c);
+		} else {
+			cmp = gaim_normalize(account, gaim_conversation_get_name(c));
+		}
+
+		if (!gaim_utf8_strcasecmp(cuser, cmp) &&
+				account == gaim_conversation_get_account(c)) {
 
 			break;
 		}
@@ -1499,7 +1512,13 @@ gaim_conversation_write(GaimConversation *conv, const char *who,
 			gaim_conv_im_set_typing_state(GAIM_CONV_IM(conv), GAIM_NOT_TYPING);
 	}
 
-	if (gaim_conv_window_get_active_conversation(win) != conv) {
+	if (gaim_conv_window_has_focus(win) &&
+		gaim_conv_window_get_active_conversation(win) == conv)
+	{
+		unseen = GAIM_UNSEEN_NONE;
+	}
+	else
+	{
 		if ((flags & GAIM_MESSAGE_NICK) == GAIM_MESSAGE_NICK ||
 				gaim_conversation_get_unseen(conv) == GAIM_UNSEEN_NICK)
 			unseen = GAIM_UNSEEN_NICK;
@@ -1510,10 +1529,29 @@ gaim_conversation_write(GaimConversation *conv, const char *who,
 		else
 			unseen = GAIM_UNSEEN_TEXT;
 	}
-	else
-		unseen = GAIM_UNSEEN_NONE;
 
 	gaim_conversation_set_unseen(conv, unseen);
+
+	/*
+	 * If we received an IM, and the GaimConvWindow is not active,
+	 * then make this conversation the active tab in this GaimConvWindow.
+	 *
+	 * We do this so that, when the user comes back to the conversation
+	 * window, the first thing they'll see is the new message.  This is
+	 * especially important when the IM window is flashing in their
+	 * taskbar--we want the title of the window to be set to the name
+	 * of the person that IMed them most recently.
+	 */
+	if ((gaim_conversation_get_type(conv) == GAIM_CONV_IM) &&
+		(flags & (GAIM_MESSAGE_RECV | GAIM_MESSAGE_ERROR)) &&
+		(!gaim_conv_window_has_focus(win)))
+	{
+		/*
+		 * This is auto-tab switching.
+		 * This is currently not enabled because people are lame.  --Mark Doliner
+		 */
+		/* gaim_conv_window_switch_conversation(win, gaim_conversation_get_index(conv)); */
+	}
 }
 
 void
@@ -1753,6 +1791,8 @@ gboolean gaim_conv_present_error(const char *who, GaimAccount *account, const ch
 	else
 		return FALSE;
 	window = gaim_conversation_get_window(conv);
+
+	/* TODO: There's a good chance this is no longer necessary */
 	if (!gaim_conv_window_has_focus(window)) /* don't change the active conversation if the user is using this window */
 		gaim_conv_window_switch_conversation(window, gaim_conversation_get_index(conv));
 
@@ -2007,7 +2047,8 @@ gaim_conv_chat_add_user(GaimConvChat *chat, const char *user, const char *extra_
 	ops  = gaim_conversation_get_ui_ops(conv);
 
 	quiet = GPOINTER_TO_INT(gaim_signal_emit_return_1(gaim_conversations_get_handle(),
-					 "chat-buddy-joining", conv, user, flags));
+					 "chat-buddy-joining", conv, user, flags)) ||
+			gaim_conv_chat_is_user_ignored(chat, user);
 
 	cb = gaim_conv_chat_cb_new(user, flags);
 
@@ -2115,7 +2156,9 @@ gaim_conv_chat_rename_user(GaimConvChat *chat, const char *old_user,
 		its_me = TRUE;
 	}
 
-	if (gaim_prefs_get_bool("/core/conversations/chat/show_nick_change")) {
+	if (gaim_prefs_get_bool("/core/conversations/chat/show_nick_change") ||
+		gaim_conv_chat_is_user_ignored(chat, new_user))
+	{
 		if(its_me) {
 			g_snprintf(tmp, sizeof(tmp),
 					_("You are now known as %s"), new_user);
@@ -2144,7 +2187,8 @@ gaim_conv_chat_remove_user(GaimConvChat *chat, const char *user, const char *rea
 	ops  = gaim_conversation_get_ui_ops(conv);
 
 	quiet = GPOINTER_TO_INT(gaim_signal_emit_return_1(gaim_conversations_get_handle(),
-				"chat-buddy-leaving", conv, user, reason));
+				"chat-buddy-leaving", conv, user, reason)) ||
+			gaim_conv_chat_is_user_ignored(chat, user);
 
 	if (ops != NULL && ops->chat_remove_user != NULL)
 		ops->chat_remove_user(conv, user);
@@ -2224,11 +2268,15 @@ gaim_conv_chat_remove_users(GaimConvChat *chat, GList *users, const char *reason
 
 		*tmp = '\0';
 
-		for (l = users, i = 0; i < max; i++, l = l->next) {
-			g_strlcat(tmp, (char *)l->data, sizeof(tmp));
+		for (l = users, i = 0; i < max; i++, l = l->next)
+		{
+			if (!gaim_conv_chat_is_user_ignored(chat, (char*)l->data))
+			{
+				g_strlcat(tmp, (char *)l->data, sizeof(tmp));
 
-			if (i < max - 1)
-				g_strlcat(tmp, ", ", sizeof(tmp));
+				if (i < max - 1)
+					g_strlcat(tmp, ", ", sizeof(tmp));
+			}
 		}
 
 		if (size > 10)
