@@ -26,6 +26,7 @@
 #include "account.h"
 #include "accountopt.h"
 #include "blist.h"
+#include "cmds.h"
 #include "debug.h"
 #include "notify.h"
 #include "privacy.h"
@@ -70,19 +71,13 @@ yahoo_rem_permit(GaimConnection *gc, const char *who)
 	gaim_privacy_permit_remove(gc->account,who,TRUE);
 }
 
-gboolean yahoo_check_privacy(GaimConnection *gc, const char *who)
+gboolean yahoo_privacy_check(GaimConnection *gc, const char *who)
 {
 	/* returns TRUE if allowed through, FALSE otherwise */
 	GSList *list;
 	gboolean permitted=FALSE;
 
 	switch (gc->account->perm_deny) {
-		case 0:
-			gaim_debug_warning("yahoo", "Privacy setting was 0.  If you can "
-							   "reproduce this, please file a bug report.\n");
-			permitted = TRUE;
-			break;
-
 		case GAIM_PRIVACY_ALLOW_ALL:
 			permitted = TRUE;
 			break;
@@ -114,8 +109,8 @@ gboolean yahoo_check_privacy(GaimConnection *gc, const char *who)
 					gaim_debug_info("yahoo",
 					    "%s blocked data received from %s (GAIM_PRIVACY_DENY_USERS)\n",
 					    gc->account->username,who);
-					}
-				break;
+					break;
+				}
 			}
 			break;
 
@@ -845,7 +840,7 @@ static void yahoo_process_notify(GaimConnection *gc, struct yahoo_packet *pkt)
 		return;
 
 	if (!g_ascii_strncasecmp(msg, "TYPING", strlen("TYPING"))
-		&& (yahoo_check_privacy(gc, from)))  {
+		&& (yahoo_privacy_check(gc, from)))  {
 		if (*stat == '1')
 			serv_got_typing(gc, from, 0, GAIM_TYPING);
 		else
@@ -927,9 +922,9 @@ static void yahoo_process_message(GaimConnection *gc, struct yahoo_packet *pkt)
 			continue;
 		}
 
-		if (!yahoo_check_privacy(gc, im->from)) {
+		if (!yahoo_privacy_check(gc, im->from)) {
 			gaim_debug_info("yahoo", "Message from %s dropped.\n", im->from);
-			continue;
+			return;
 		}
 
 		m = yahoo_string_decode(gc, im->msg, im->utf8);
@@ -2119,7 +2114,10 @@ static void yahoo_process_audible(GaimConnection *gc, struct yahoo_packet *pkt)
 		gaim_debug_misc("yahoo", "Warning, nonutf8 audible, ignoring!\n");
 		return;
 	}
-
+	if (!yahoo_privacy_check(gc, who)) {
+		gaim_debug_misc("yahoo", "Audible message from %s for %s dropped!\n", gc->account->username, who);
+		return;
+	}
 	serv_got_im(gc, who, msg, 0, time(NULL));
 }
 
@@ -3211,6 +3209,9 @@ static void yahoo_add_buddy(GaimConnection *gc, GaimBuddy *buddy, GaimGroup *foo
 	if (!yd->logged_in)
 		return;
 
+	if (!yahoo_privacy_check(gc, buddy->name))
+		return;
+
 	if (foo)
 		group = foo->name;
 	if (!group) {
@@ -3380,6 +3381,7 @@ static void yahoo_change_buddys_group(GaimConnection *gc, const char *who,
 	yahoo_send_packet(yd, pkt);
 	yahoo_packet_free(pkt);
 
+#if 0
 	/* Step 2:  Remove buddy from old group */
 	pkt = yahoo_packet_new(YAHOO_SERVICE_REMBUDDY, YAHOO_STATUS_AVAILABLE, 0);
 	yahoo_packet_hash(pkt, 1, gaim_connection_get_display_name(gc));
@@ -3387,6 +3389,7 @@ static void yahoo_change_buddys_group(GaimConnection *gc, const char *who,
 	yahoo_packet_hash(pkt, 65, gpo);
 	yahoo_send_packet(yd, pkt);
 	yahoo_packet_free(pkt);
+#endif
 	g_free(gpn);
 	g_free(gpo);
 }
@@ -3418,6 +3421,69 @@ static void yahoo_rename_group(GaimConnection *gc, const char *old_name,
 
 static GaimPlugin *my_protocol = NULL;
 
+/********************************* Commands **********************************/
+
+static GaimCmdRet
+yahoogaim_cmd_buzz(GaimConversation *c, const gchar *cmd, gchar **args,
+					gchar **error, void *data) {
+
+	GaimAccount *account = gaim_conversation_get_account(c);
+	const char *username = gaim_account_get_username(account);
+
+	if (*args && args[0])
+		return GAIM_CMD_RET_FAILED;
+
+	gaim_debug(GAIM_DEBUG_INFO, "yahoo",
+	           "Sending <ding> on account %s to buddy %s.\n", username, c->name);
+	gaim_conv_im_send(GAIM_CONV_IM(c), "<ding>");
+	gaim_conv_im_write(GAIM_CONV_IM(c), "", _("Buzz!!"), 
+		GAIM_MESSAGE_NICK|GAIM_MESSAGE_RECV, time(NULL));
+	return GAIM_CMD_RET_OK;
+}
+
+static GaimCmdRet
+yahoogaim_cmd_chat_join(GaimConversation *conv, const char *cmd,
+                        char **args, char **error, void *data)
+{
+	GHashTable *comp;
+	GaimConnection *gc;
+	struct yahoo_data *yd;
+	int id;
+
+	if (!args || !args[0])
+		return GAIM_CMD_RET_FAILED;
+
+	gc = gaim_conversation_get_gc(conv);
+	yd = gc->proto_data;
+	id = yd->conf_id;
+	gaim_debug(GAIM_DEBUG_INFO, "yahoo",
+	           "Trying to join %s \n", args[0]);
+
+	comp = g_hash_table_new_full(g_str_hash, g_str_equal, g_free, g_free);
+	g_hash_table_replace(comp, g_strdup("room"),
+	g_strdup_printf("%s", g_ascii_strdown(args[0], strlen(args[0]))));
+	g_hash_table_replace(comp, g_strdup("type"), g_strdup("Chat"));
+
+	yahoo_c_join(gc, comp);
+
+	g_hash_table_destroy(comp);
+	return GAIM_CMD_RET_OK;
+}
+
+/************************** Plugin Initialization ****************************/
+static void
+yahoogaim_register_commands(void)
+{
+	gaim_cmd_register("join", "s", GAIM_CMD_P_PRPL,
+	                  GAIM_CMD_FLAG_IM | GAIM_CMD_FLAG_CHAT |
+	                  GAIM_CMD_FLAG_PRPL_ONLY,
+	                  "prpl-yahoo", yahoogaim_cmd_chat_join,
+	                  _("join &lt;room&gt;:  Join a chat room on the Yahoo network"), NULL);
+	gaim_cmd_register("buzz", "", GAIM_CMD_P_PRPL,
+	                  GAIM_CMD_FLAG_IM | GAIM_CMD_FLAG_PRPL_ONLY,
+	                  "prpl-yahoo", yahoogaim_cmd_buzz,
+	                  _("buzz: Buzz a contact to get their attention"), NULL);
+}
 static GaimPluginProtocolInfo prpl_info =
 {
 	OPT_PROTO_MAIL_CHECK | OPT_PROTO_CHAT_TOPIC,
@@ -3548,7 +3614,7 @@ init_plugin(GaimPlugin *plugin)
 #endif
 
 	my_protocol = plugin;
-
+	yahoogaim_register_commands();
 	yahoo_init_colorht();
 }
 
